@@ -27,12 +27,16 @@ import sys
 """
 帮助文档：https://github.com/aliyun/aliyun-datahub-sdk-python
 中文文档：https://pydatahub.readthedocs.io/zh_CN/latest/
+
+错误列表：
+status_code: 403, request_id: 20*****************cd, error_code: NoPermission, error_msg: You do not have the corresponding permissions, please grant first.
 """
 urllib3.disable_warnings()
+default_env_file_name = 'aliyun.datahub.env'
 
 
 def make_con_info(
-        env_file_name: str = 'aliyun.datahub.env'
+        env_file_name: str = default_env_file_name
 ):
     inner_env = envx.read(file_name=env_file_name)
     if inner_env is None or len(inner_env) == 0:
@@ -390,7 +394,7 @@ def project_create(
         comment: str = 'comment',
 
         con_info: dict = None,  # 若指定，将优先使用
-        env_file_name: str = 'aliyun.datahub.env',
+        env_file_name: str = default_env_file_name,
 ):
     # ---------------- 固定设置 ----------------
     if con_info is None:
@@ -407,7 +411,7 @@ def project_create(
 
 def project_list(
         con_info: dict = None,  # 若指定，将优先使用
-        env_file_name: str = 'aliyun.datahub.env',
+        env_file_name: str = default_env_file_name,
 ):
     # ---------------- 固定设置 ----------------
     if con_info is None:
@@ -428,7 +432,7 @@ def blob_topic_create(
         extend_mode=True,  # Shard扩展模式：默认是
 
         con_info: dict = None,  # 若指定，将优先使用
-        env_file_name: str = 'aliyun.datahub.env',
+        env_file_name: str = default_env_file_name,
 ):
     """
     创建topic
@@ -458,7 +462,7 @@ def blob_records_add(
         shard_id='0',  # 指定shard_id，默认为'0'
 
         con_info: dict = None,  # 若指定，将优先使用
-        env_file_name: str = 'aliyun.datahub.env',
+        env_file_name: str = default_env_file_name,
 
         project_auto_create: bool = False,  # 自动创建project
         topic_auto_create: bool = False,  # 自动创建topic
@@ -524,7 +528,7 @@ def blob_records_read(
         shard_id='0',  # 指定shard_id，默认为'0'
 
         con_info: dict = None,  # 若指定，将优先使用
-        env_file_name: str = 'aliyun.datahub.env',
+        env_file_name: str = default_env_file_name,
 ):
     # ---------------- 固定设置 ----------------
     if con_info is None:
@@ -545,7 +549,7 @@ def blob_records_read(
 def topic_list(
         project_name: str,
         con_info: dict = None,  # 若指定，将优先使用
-        env_file_name: str = 'aliyun.datahub.env',
+        env_file_name: str = default_env_file_name,
 ) -> list:
     """
     获取topic列表
@@ -604,6 +608,12 @@ def lazy_save(
             add_response_code = add_response.get('code')
             if add_response_code == 0:
                 return save_res
+            elif add_response_code == 403:
+                message = add_response.get('message')
+                save_res['code'] = add_response_code
+                save_res['msg'] = message
+                save_res['success'] = False
+                return save_res
             elif add_response_code == 404:
                 message = add_response.get('message')
                 save_res['code'] = add_response_code
